/*
 * Implementation of "Visualization of Large Terrains Made Easy"
 * (Lindstrom and Pascucci) with geomorphing, embedded quadtree
 * indexing, view frustum culling, and multithreaded refinement
 *
 * Copyright (c) 2002 Jan Wassenberg
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * Contact info:
 *   Jan.Wassenberg@stud.uni-karlsruhe.de
 *   http://www.stud.uni-karlsruhe.de/~urkt/
 */

#ifndef __LOD_H__
#define __LOD_H__


#ifdef __cplusplus
extern "C" {
#endif


/* preprocess a heightmap of width 2^x + 1 (x >= 2) */
extern int lod_preproc(const uint width, uchar* hmap);

/*
 * load data saved by lod_save_preproc_data()
 * equivalent to lod_preproc() on the original data
 */
extern int lod_load_preproc_data(const char* filename);

/* save all state calculated by lod_preproc() to <filename> */
extern int lod_save_preproc_data(const char* filename);

/*
 * extract current view position / direction from OpenGL
 * (needed for LOD metric)
 */
extern void lod_latch_view_pos();

extern void lod_render();


#ifdef __cplusplus
}
#endif


#endif	/* #ifndef __LOD_H__ */