#ifndef __WSDL_H__
#define __WSDL_H__


#ifndef WIN32

#include <SDL/sdl.h>

#else

#define WIN32_LEAN_AND_MEAN
#include <windows.h>


/* video */

#define SDL_GL_GetProcAddress wglGetProcAddress
#define SDL_GL_SetAttribute(a, v)
extern int SDL_SetVideoMode(int w, int h, int bpp, uint32 flags);
extern void SDL_GL_SwapBuffers();


/************************************************************************************************
 * init
 ************************************************************************************************/

/* SDL_Init flags */
#define SDL_INIT_VIDEO 0
#define SDL_INIT_AUDIO 0
#define SDL_INIT_TIMER 0
#define SDL_INIT_NOPARACHUTE 0

/* SDL_SetVideoMode() flags */
#define SDL_OPENGL 0
#define SDL_FULLSCREEN 1

extern int SDL_Init(uint32);
extern void SDL_Quit();


/************************************************************************************************
 * events
 ************************************************************************************************/

/* SDLKey (mapped to VK_* codes) */
typedef enum
{
	SDLK_ESCAPE	= 0x1b,
	SDLK_8 = '8',
	SDLK_9 = '9',
	SDLK_0 = '0',
	SDLK_p = 'P',
	SDLK_r = 'R',
	SDLK_s = 'S'
}
SDLKey;

typedef struct
{
	SDLKey sym;
}
SDL_keysym;

typedef struct
{
	SDL_keysym keysym;
}
SDL_KeyboardEvent;

typedef struct
{
	uint16 x, y;
}
SDL_MouseMotionEvent;

/* SDL_Event.type */
enum
{
	SDL_KEYDOWN,		// do not change!
	SDL_KEYUP,			// SDL_PollEvent() relies on these values
	SDL_MOUSEMOTION
};

typedef struct
{
	uint8 type;
	union
	{
		SDL_KeyboardEvent key;
		SDL_MouseMotionEvent motion;
	};
}
SDL_Event;

extern int SDL_PollEvent(SDL_Event* ev);


/************************************************************************************************
 * threads / synchronization
 ************************************************************************************************/

#define SDL_CreateSemaphore(cnt) (SDL_semaphore*)CreateSemaphore(0, cnt, 0x7fffffff, 0)
#define SDL_DestroySemaphore(sem) CloseHandle(sem)
#define SDL_SemPost(sem) ReleaseSemaphore(sem, 1, NULL)
#define SDL_SemWait(sem) WaitForSingleObject(sem, INFINITE)

#ifndef _SDL_thread_h
typedef void SDL_Thread;
#endif

typedef int (*SDL_THREAD_PROC)(void*);

#define SDL_KillThread(thread) TerminateThread(thread, 0)
extern "C" SDL_Thread* SDL_CreateThread(SDL_THREAD_PROC proc, void* param);


/* misc */

#define SDL_WarpMouse(x, y) SetCursorPos(x, y)
#define SDL_GRAB_ON 0
#define SDL_WM_GrabInput(a)
#define SDL_GetError() ""
extern uint32 SDL_GetTicks();


#endif	/* #else / #ifndef WIN32 */

#endif	/* #ifndef __WSDL_H__ */